<?php
/**
 * file semmelstatzR_log.php
 *
 * @package     SemmelstatzR
 * @version     $Rev$
 * @since       1.0.0
 * @author      SEM-Team
 * @copyright   (c)2011 SEM-Team
 * @link        http://sourceforge.net/projects/semmelstatz/
 * @license     http://www.gnu.org/licenses/gpl-3.0.html
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.  
 *
 * $Id$
 * 
 */
/**  
 * based upon semmelstatz
 * Copyright (c) 2005-2009 Andreas 'Redunzl' Mueller (redunzl@gmx.de)
 *    
 * @license http://www.gnu.org/licenses/gpl-2.0.html
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (version 2) as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

if(!current_user_can('manage_statz')) {
    die(semr_i18n("Restricted Area"));
}

global $wpdb;
		
$sem_options = get_option('semmelstatzR_options'); ### optionsarray auslesen
$limit = $sem_options["statz_datarecs_limit"]; $mask = $sem_options["statz_mask_referer"];
$completerecords = $wpdb->get_results("SELECT id, ip, time, referer, page, username FROM ".
        $wpdb->statz." ORDER BY time DESC LIMIT 0, ".$limit);
        
print "<div class='wrap'>";
print "<div id='icon-semmelstatzR' class='icon32'><br /></div>";
print "<h2>SemmelstatzR &gt; ".semr_i18n("Log")."</h2>";
print "<div class='statz'>";
printf(semr_i18n("The %s newest records"), $limit);
print "</div>";

if ($completerecords == NULL) {
    print '<small>... '.  semr_i18n("no entries at all").'</small>';
    return;
}

print "<table cellpadding='5' style='text-align:center; width:100%;'>";
print "<thead>";
print "<tr>";
print "<th style='text-align:center;width:110px;'><small>".semr_i18n("Date")."</small></th>";
print "<th style='text-align:center;width:80px;'><small>".semr_i18n("TCP/IP")."</small></th>";
print "<th style='text-align:left;'><small>".semr_i18n("Referrer")."</small></th>";
print "<th style='text-align:left;'><small>".semr_i18n("Search term")."</small></th>";
print "<th style='text-align:left;'><small>".semr_i18n("Post/Page")."</small></th>";
print "<th style='text-align:left;'><small>".semr_i18n("Username")."</small></th>";
print "</tr>";
print "</thead>";
print "<tbody>";

foreach ($completerecords as $key=>$completerecord) {
$id = $completerecord->id;
$ip = $completerecord->ip;
if(sem_checkIfIPisEncoded($ip) == true) $ip = sem_decodeIP($ip);
$date = mysql2date("d.m.Y G:i", $completerecord->time);
$referer = $completerecord->referer;
if($referer == "") {
$referer = "--";
}
else {
if(strlen($referer) >= 50) {
$printreferer = substr($referer, 0, 50)."...";
}
else {
$printreferer = $referer;
}
}
$keyword = sem_getKeyword($referer);
if(empty($keyword)) $keyword ='--';
$page = $completerecord->page;
if ($page == 0) {
$link = get_option('siteurl');
$title = "0"; //oder wie auch immer
}
else {
$link = get_permalink($page);
$postarray = get_post($page, ARRAY_A);
$title = $postarray['post_title'];
}
$username = $completerecord->username;
print "<tr"; if(1&$key) print " class='alternate'"; print ">";
print "<td style='white-space:nowrap;text-align:center;'><small>".$date."</small></td>";
print "<td style='white-space:nowrap;text-align:center;'>
<a target='_blank' style='border:none;' href='http://ws.arin.net/whois/?queryinput=".$ip."'>
<img src='".get_option('siteurl')."/wp-content/plugins/semmelstatzR/img/arin.png' /></a>&nbsp;
<a target='_blank' style='border:none;' href='http://www.ripe.net/whois?searchtext=".$ip."'>
<img src='".get_option('siteurl')."/wp-content/plugins/semmelstatzR/img/ripe.png' /></a>&nbsp;
<a target='_blank' style='border:none;' href='http://www.utrace.de/?query=".$ip."'>
<img src='".get_option('siteurl')."/wp-content/plugins/semmelstatzR/img/utrace.png' /></a></td>";
print "<td style='text-align:left;'><small>";
if ($referer == "--") {
print "--</small></td>";
}
else {
if($mask != true) {
print "<a target='_blank' style='text-decoration:none;' href='".$referer."'>".$printreferer."</a></td>";
}
else {
$referer = htmlspecialchars($referer, ENT_QUOTES);
print "<a target='_blank' style='text-decoration:none;' href='http://www.google.com/url?sa=D&q=".$referer."'>".$printreferer."</a></td>";
}
}

print "<td style='text-align:left;'><small>".$keyword."</small></td>";
print "<td style='text-align:left;'><small><a target='_blank' style='text-decoration:none;' href='".$link."'>".$title."</small></td>";
print "<td style='text-align:left;'><small>".$username."</small></td>";
print "</tr>";
}

print "</tbody>";
print "</table>";
print "<hr />";

if (function_exists('sem_showCopyright')) sem_showCopyright();

print "</div>";

?>